{% for field in fields %}
{% if field.is_hidden %}
{{ field }}
{% else %}
<li{{ field.row_attrs }}>
  {{ field.errors }}
  <label for="{{ field.auto_id }}">
  {{ field.label }}
  </label>
  {{ field }}
</li>
{% endif %}
{% endfor %}
